@@ -1,15 +1,14 @@
-package # hide from PAUSE
-    Class::XSAccessor::Heavy;
+package Class::XSAccessor::Heavy;
 
-use 5.008;
+use 5.006;
 use strict;
 use warnings;
 use Carp;
 
-our $VERSION  = '1.12_02';
+our $VERSION  = '1.05';
 our @CARP_NOT = qw(
-        Class::XSAccessor
-        Class::XSAccessor::Array
+	Class::XSAccessor
+	Class::XSAccessor::Array
 );
 
 # TODO Move more duplicated code from XSA and XSA::Array here
@@ -62,11 +61,11 @@ L<Class::XSAccessor::Array>
 
 Steffen Mueller, E<lt>smueller@cpan.orgE<gt>
 
-chocolateboy, E<lt>chocolate@cpan.orgE<gt>
+Chocolateboy, E<lt>chocolate@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008, 2009, 2010, 2011 by Steffen Mueller
+Copyright (C) 2008-2009 by Steffen Mueller
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8 or,
